@@ -8,10 +8,11 @@ from progress_table import ProgressTable
 progress = ProgressTable(columns=["step", "x", "x squared"], num_decimal_places=10)
 progress.add_column("x root", color=Fore.RED, width=12)
 
-for step in range(20):
+for step in progress(range(20)):
     progress["step"] = step  # insert step value in the current row
 
-    for _ in progress(range(10)):  # display progress bar
+    for _ in range(10):  # display progress bar
+        progress["x"] = 1
         time.sleep(0.1)  # simulate artificial work
 
     x = random.randint(0, 200)
